==> sklearn_plus-0.0.3.tar.gz: sklearn_plus-0.0.3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    "jieba","scikit-learn","tensorflow==1.2.0","numpy","scipy","nltk","pandas"
]

setup_requirements = [
    # TODO(ybbaigo): Put setup requirements (distutils extensions, etc.) here
]

test_requirements = [
    "jieba","scikit-learn","tensorflow==1.2.0","numpy","scipy","nltk","pandas"
]

setup(
    name='sklearn_plus',
    version='0.0.3',
    description="A set of python modules for Natural Language Processing",
    long_description=readme,
    author="Yuwen Yan",
    author_email='ybbaigo@gmail.com',
    url='https://github.com/ybbaigo/sklearn-plus',
    packages=find_packages(include=['sklearn_plus']),
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords='sklearn_plus',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)

==> sklearn_plus-0.0.4.tar.gz: sklearn_plus-0.0.4/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
    "jieba","scikit-learn","tensorflow==1.2.0","numpy","scipy","nltk","pandas", 'dill', 'numpy>=1.11.0'
]

setup_requirements = [
    # TODO(ybbaigo): Put setup requirements (distutils extensions, etc.) here
]

test_requirements = [
    "jieba","scikit-learn","tensorflow==1.2.0","numpy","scipy","nltk","pandas"
]

setup(
    name='sklearn_plus',
    version='0.0.4',
    description="A set of python modules for Natural Language Processing",
    long_description=readme,
    author="Yuwen Yan",
    author_email='ybbaigo@gmail.com',
    url='https://github.com/ybbaigo/sklearn-plus',
    packages=find_packages(include=[
        'sklearn_plus',
        'sklearn_plus.natural_language_processing',
        'sklearn_plus.natural_language_processing.text_classification',
        'sklearn_plus.natural_language_processing.text_classification.model_fn',
        'sklearn_plus.utils',
    ]),
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=False,
    keywords='sklearn_plus',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    setup_requires=setup_requirements,
)
